part of 'field_bloc.dart';

abstract class FieldState extends Equatable {
  const FieldState();
  
  @override
  List<Object?> get props => [];
}

class FieldInitial extends FieldState {}

class FieldLoading extends FieldState {}

class FieldLoaded extends FieldState {
  final List<Field> fields;
  
  const FieldLoaded({required this.fields});
  
  @override
  List<Object?> get props => [fields];
}

class FieldError extends FieldState {
  final String message;
  
  const FieldError({required this.message});
  
  @override
  List<Object?> get props => [message];
}

class FieldOperationInProgress extends FieldState {}

class FieldOperationSuccess extends FieldState {}

class FieldOperationFailure extends FieldState {
  final String message;
  
  const FieldOperationFailure({required this.message});
  
  @override
  List<Object?> get props => [message];
} 